package hdl

import (
	"applet/app/admin/lib/validate"
	"applet/app/customer/md"
	svc "applet/app/customer/svc/order"
	"applet/app/db"
	"applet/app/db/model"
	"applet/app/e"
	"applet/app/enum"
	"applet/app/utils"
	"encoding/json"
	"github.com/gin-gonic/gin"
	"time"
)

func NursingHomeOrderList(c *gin.Context) {
	var req md.NursingHomeOrderListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	list, total, err := svc.NursingHomeOrderList(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	sumTotal, err := svc.NursingHomeOrderStatistic(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, map[string]interface{}{
		"list":      list,
		"sum_total": sumTotal,
		"total":     total,
		"ord_state_list": []map[string]interface{}{
			{
				"name":  enum.NursingHomePackageOrdOrdState.String(enum.NursingHomePackageOrdOrdStateForWait),
				"value": enum.NursingHomePackageOrdOrdStateForWait,
			},
			{
				"name":  enum.NursingHomePackageOrdOrdState.String(enum.NursingHomePackageOrdOrdStateForSuccess),
				"value": enum.NursingHomePackageOrdOrdStateForSuccess,
			},
			{
				"name":  enum.NursingHomePackageOrdOrdState.String(enum.NursingHomePackageOrdOrdStateForRefunding),
				"value": enum.NursingHomePackageOrdOrdStateForRefunding,
			},
			{
				"name":  enum.NursingHomePackageOrdOrdState.String(enum.NursingHomePackageOrdOrdStateForPartRefunded),
				"value": enum.NursingHomePackageOrdOrdStateForPartRefunded,
			},
			{
				"name":  enum.NursingHomePackageOrdOrdState.String(enum.NursingHomePackageOrdOrdStateForRefunded),
				"value": enum.NursingHomePackageOrdOrdStateForRefunded,
			},
			{
				"name":  enum.NursingHomePackageOrdOrdState.String(enum.NursingHomePackageOrdOrdStateForComplete),
				"value": enum.NursingHomePackageOrdOrdStateForComplete,
			},
		},
		"kind_list": []map[string]string{
			{
				"name":  "按年购买",
				"value": "1",
			},
			{
				"name":  "按月购买",
				"value": "2",
			},
			{
				"name":  "按天购买",
				"value": "3",
			},
			{
				"name":  "补餐",
				"value": "4",
			},
		},
	}, nil)
	return
}

func NursingHomeOrderDetail(c *gin.Context) {
	outTradeNo := c.DefaultQuery("out_trade_no", "")
	NursingHomePackageOrd := db.NursingHomePackageOrd{}
	NursingHomePackageOrd.Set(outTradeNo)
	ord, err := NursingHomePackageOrd.GetNursingHomePackageOrd()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if ord == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应订单记录")
		return
	}

	var total, totalBreakfast, totalLunch, totalDinner int
	var list []*model.NursingHomeUserWithDay
	err1 := json.Unmarshal([]byte(ord.WithDayData), &list)
	if err1 != nil {
		e.OutErr(c, e.ERR, err1.Error())
		return
	}
	total = len(list)
	for _, v := range list {
		if v.Kind == enum.NursingHomeUserWithDayKindForBreakfast {
			totalBreakfast++
		}
		if v.Kind == enum.NursingHomeUserWithDayKindForLunch {
			totalLunch++
		}
		if v.Kind == enum.NursingHomeUserWithDayKindForDinner {
			totalDinner++
		}
	}

	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(ord.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	e.OutSuc(c, map[string]interface{}{
		"enterprise":      enterprise,
		"total":           total,
		"ord_info":        ord,
		"total_breakfast": totalBreakfast,
		"total_lunch":     totalLunch,
		"total_dinner":    totalDinner,
		"ord_state_list": []map[string]interface{}{
			{
				"name":  enum.NursingHomePackageOrdOrdState.String(enum.NursingHomePackageOrdOrdStateForWait),
				"value": enum.NursingHomePackageOrdOrdStateForWait,
			},
			{
				"name":  enum.NursingHomePackageOrdOrdState.String(enum.NursingHomePackageOrdOrdStateForSuccess),
				"value": enum.NursingHomePackageOrdOrdStateForSuccess,
			},
			{
				"name":  enum.NursingHomePackageOrdOrdState.String(enum.NursingHomePackageOrdOrdStateForRefunding),
				"value": enum.NursingHomePackageOrdOrdStateForRefunding,
			},
			{
				"name":  enum.NursingHomePackageOrdOrdState.String(enum.NursingHomePackageOrdOrdStateForPartRefunded),
				"value": enum.NursingHomePackageOrdOrdStateForPartRefunded,
			},
			{
				"name":  enum.NursingHomePackageOrdOrdState.String(enum.NursingHomePackageOrdOrdStateForRefunded),
				"value": enum.NursingHomePackageOrdOrdStateForRefunded,
			},
			{
				"name":  enum.NursingHomePackageOrdOrdState.String(enum.NursingHomePackageOrdOrdStateForComplete),
				"value": enum.NursingHomePackageOrdOrdStateForComplete,
			},
		},
		"kind_list": []map[string]string{
			{
				"name":  "按年购买",
				"value": "1",
			},
			{
				"name":  "按月购买",
				"value": "2",
			},
			{
				"name":  "按天购买",
				"value": "3",
			},
			{
				"name":  "补餐",
				"value": "4",
			},
		},
	}, nil)
	return
}

func NursingHomeOrderBelowWithDay(c *gin.Context) {
	outTradeNo := c.DefaultQuery("out_trade_no", "")
	NursingHomePackageOrd := db.NursingHomePackageOrd{}
	NursingHomePackageOrd.Set(outTradeNo)
	ord, err := NursingHomePackageOrd.GetNursingHomePackageOrd()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if ord == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应订单记录")
		return
	}
	NursingHomeUserWithDayDb := db.NursingHomeUserWithDayDb{}
	NursingHomeUserWithDayDb.Set(0)
	list, err := NursingHomeUserWithDayDb.FindNursingHomeUserWithDayByOrdNoAndState(ord.OutTradeNo, enum.NursingHomeUserWithDayStateForWait)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	e.OutSuc(c, map[string]interface{}{
		"list":               list,
		"allow_refund_state": enum.NursingHomeUserWithDayStateForWait,
		"kind_list": []map[string]interface{}{
			{
				"name":  enum.NursingHomeUserWithDayKind.String(enum.NursingHomeUserWithDayKindForBreakfast),
				"value": enum.NursingHomeUserWithDayKindForBreakfast,
			},
			{
				"name":  enum.NursingHomeUserWithDayKind.String(enum.NursingHomeUserWithDayKindForLunch),
				"value": enum.NursingHomeUserWithDayKindForLunch,
			},
			{
				"name":  enum.NursingHomeUserWithDayKind.String(enum.NursingHomeUserWithDayKindForDinner),
				"value": enum.NursingHomeUserWithDayKindForDinner,
			},
		},
	}, nil)
	return
}

func NursingHomeOrderRefund(c *gin.Context) {
	var req md.NursingHomeOrderRefundReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	err = svc.NursingHomeOrderRefund(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func NursingHomeOrderRefundList(c *gin.Context) {
	var req md.NursingHomeOrderRefundListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	list, total, err := svc.NursingHomeOrderRefundList(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, map[string]interface{}{
		"list":  list,
		"total": total,
		"kind_list": []map[string]interface{}{
			{
				"name":  enum.NursingHomeUserWithDayKind.String(enum.NursingHomeUserWithDayKindForBreakfast),
				"value": enum.NursingHomeUserWithDayKindForBreakfast,
			},
			{
				"name":  enum.NursingHomeUserWithDayKind.String(enum.NursingHomeUserWithDayKindForLunch),
				"value": enum.NursingHomeUserWithDayKindForLunch,
			},
			{
				"name":  enum.NursingHomeUserWithDayKind.String(enum.NursingHomeUserWithDayKindForDinner),
				"value": enum.NursingHomeUserWithDayKindForDinner,
			},
		},
		"state_list": []map[string]interface{}{
			{
				"name":  enum.NursingHomeUserRefundDayState.String(enum.NursingHomeUserRefundDayStateForAuditing),
				"value": enum.NursingHomeUserRefundDayStateForAuditing,
			},
			{
				"name":  enum.NursingHomeUserRefundDayState.String(enum.NursingHomeUserRefundDayStateForAuditPass),
				"value": enum.NursingHomeUserRefundDayStateForAuditPass,
			},
			{
				"name":  enum.NursingHomeUserRefundDayState.String(enum.NursingHomeUserRefundDayStateForAuditReject),
				"value": enum.NursingHomeUserRefundDayStateForAuditReject,
			},
			{
				"name":  enum.NursingHomeUserRefundDayState.String(enum.NursingHomeUserRefundDayStateForAuditComplete),
				"value": enum.NursingHomeUserRefundDayStateForAuditComplete,
			},
		},
	}, nil)
	return
}

func NursingHomeMyReserve(c *gin.Context) {
	date := c.DefaultQuery("date", "")
	userIdentityId := c.DefaultQuery("user_identity_id", "")
	if date == "" {
		e.OutErr(c, e.ERR_INVALID_ARGS, "日期不能为空")
		return
	}
	startDate := date + "-01"
	startDateTime, _ := time.ParseInLocation("2006-01-02", startDate, time.Local)
	endDate := startDateTime.AddDate(0, 1, -1).Format("2006-01-02")
	err, resp := svc.NursingHomeMyReserve(utils.StrToInt(userIdentityId), date, startDate, endDate)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, map[string]interface{}{
		"info": resp,
	}, nil)
	return
}
